﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace WisejWebPageApplication1.Models
{
    public partial class ViewPratiche : ICloneable
    {
        public bool IsRecuperoIva
        {
            get
            {
                // pratica assicurata, cliente aziendale e percentuale recupero maggiore di zero
                return (this.TipologiaPratica.Equals("A") || this.TipologiaPratica.Equals("F")) &&
                    (TipologiaClienti != null && TipologiaClienti.Equals("A")) &&
                    (ScaricatoVeicoli != null && ScaricatoVeicoli > 0);
            }
        }

        public decimal? ValueRecuperoIva
        {
            get
            {
                decimal? retValue = null;

                if (IsRecuperoIva)
                {
                    // calcolo l'iva in proporzione
                    decimal iva = this.TotaleVenditaPratica - this.TotaleImpVenditaPratica;
                    retValue = iva * ScaricatoVeicoli;
                }

                return retValue;
            }
        }

        public bool HasFattura
        {
            get
            {
                if (this.IDFattura != null)
                {
                    return true;
                }
                else
                {
                    return false;
                }
            }
        }

        public bool TipologiaDocumentoCI { get; set; } = false;

        public bool TipologiaDocumentoCF { get; set; } = false;

        public bool TipologiaDocumentoLibretto { get; set; } = false;

        public bool TipologiaDocumentoPolizza { get; set; } = false;

        public bool TipologiaDocumentoModulo { get; set; } = false;

        public bool TipologiaDocumentoVisura { get; set; } = false;

        public bool TipologiaDocumentoFoto { get; set; } = false;

        public bool SollecitoReclamoCompletato
        {
            get
            {
                bool retValue = true;

                if (this.SollecitoPresente.HasValue && (bool)this.SollecitoPresente)
                {

                    if (this.StatoPratica.Contains("MIVA") || this.StatoPratica.Contains("MLIQ") || this.StatoPratica.Contains("ALIQ"))
                    {
                        retValue = false;
                    }
                }

                return retValue;
            }
        }

        // utilizzata in giornaliero per gestire gli appuntamenti delle garanzie
        public Garanzie SelectedGaranzia { get; set; }

        #region Display

        public string DisplayStatoEstesoPraticheStati
        {
            get
            {
                return StatoPratica;
            }
        }

        public string DisplayTipologiaPratica
        {
            get
            {
                string retValue = null;

                if (!string.IsNullOrWhiteSpace(this.TipologiaPratica))
                {

                    switch (this.TipologiaPratica.ToUpper())
                    {
                        case "A":
                            retValue = "ASSICURATO";
                            break;
                        case "F":
                            retValue = "FATTO POINT";
                            break;
                        case "P":
                            retValue = "PREVENTIVO";
                            break;
                        case "M":
                            retValue = "MANODOPERA";
                            break;
                    }
                }

                return retValue;
            }
        }

        public DateTime? DisplayDataOraInterventi
        {
            get
            {
                if (SelectedGaranzia == null)
                {
                    return DataOraInterventi;
                }
                else
                {
                    return null;
                     // return this.SelectedGaranzia?.Interventi?.DataOra;
                }

            }
        }

        public string DisplayRimborsoKmFitter
        {
            get
            {
                decimal rimbKm = 0;


                if (this.RimborsoKmFitter.HasValue)
                {
                    rimbKm += (decimal)this.RimborsoKmFitter;
                }

                if (this.RimborsoKmFitter2.HasValue)
                {
                    rimbKm += (decimal)this.RimborsoKmFitter2;
                }

                return rimbKm.ToString("N2");
            }
        }

        public string DisplayNumeroFattura
        {
            get
            {
                string retValue = null;

                if (!string.IsNullOrWhiteSpace(NumeroFICFattura) && this.DataFattura.HasValue)
                {
                    return $"{this.NumeroFICFattura}/{((DateTime)this.DataFattura).Date.Year}";
                }

                return retValue;
            }
        }

        public decimal? DisplayPrevisioneNotaCredito
        {
            get
            {
                decimal? valore = null;

                if (this.PrevLiquidazionePratica != null)
                {
                    if (this.PrevLiquidazionePratica < this.TotaleVenditaPratica)
                    {
                        valore = this.TotaleVenditaPratica - (decimal)this.PrevLiquidazionePratica;
                    }
                    else
                    {
                        valore = 0;
                    }
                }

                return valore;
            }
        }

        public decimal? DisplayPrevisioneStornoNotaCredito
        {
            get
            {
                decimal? valore = null;
                decimal? prevNotaCredito = this.DisplayPrevisioneNotaCredito;

                //if (prevNotaCredito != null)
                //{
                //    if (this.StornoNotaPercenutalePratica == 0)
                //    {
                //        valore = (decimal)prevNotaCredito * Helper
                //            .ParsePerc(Globals.DEFAULT_STORNO_NOTE_CREDITO);
                //    }
                //    else
                //    {
                //        valore = (decimal)prevNotaCredito * this.StornoNotaPercenutalePratica;
                //    }
                //}

                return valore;
            }
        }

        public decimal? DisplayValoreNotaCredito
        {
            get
            {
                decimal? valore = null;

                // note credito tradizionali
                if (this.ValoreNettoFICNoteCreditoTradizionali.HasValue)
                {
                    valore = (decimal)this.ValoreNettoFICNoteCreditoTradizionali;
                }
                else if (this.ValoreNettoNoteCreditoPatrimoniali.HasValue) // note di credito patrimoniali
                {
                    valore = (decimal)this.ValoreNettoNoteCreditoPatrimoniali;
                }

                return valore;
            }
        }

        public DateTime? DisplayDataInvioNotaCredito
        {
            get
            {
                DateTime? retValue = null;

                // note credito tradizionali
                if (this.DataInvioNoteCreditoTradizionali.HasValue)
                {
                    retValue = this.DataInvioNoteCreditoTradizionali;
                }
                else if (this.DataInvioNoteCreditoPatrimoniali.HasValue) // note di credito patrimoniali
                {
                    retValue = this.DataInvioNoteCreditoPatrimoniali;
                }

                return retValue;
            }
        }

        public string DisplayDestinatarioInvioNotaCredito
        {
            get
            {
                string retValue = null;

                // note credito tradizionali
                if (!string.IsNullOrWhiteSpace(this.DestinatarioInvioNoteCreditoTradizionali))
                {
                    retValue = this.DestinatarioInvioNoteCreditoTradizionali;
                }
                else if (!string.IsNullOrWhiteSpace(this.DestinatarioInvioNoteCreditoPatrimoniali)) // note di credito patrimoniali
                {
                    retValue = this.DestinatarioInvioNoteCreditoPatrimoniali;
                }

                return retValue;
            }
        }

        public decimal? DisplayStornoNotaCredito
        {
            get
            {
                decimal? valore = null;


                // note credito tradizionali
                if (this.ValoreNettoFICNoteCreditoTradizionali.HasValue)
                {
                    valore = 0;
                }
                else if (this.ValoreNettoNoteCreditoPatrimoniali.HasValue) // note di credito patrimoniali
                {
                    valore = (decimal)this.ValoreNettoNoteCreditoPatrimoniali * this.StornoNotaPercenutalePratica;
                }

                return valore;
            }
        }

        #endregion

        public object Clone()
        {
            return this.MemberwiseClone();
        }

        public override bool Equals(object obj)
        {
            if (obj is ViewPratiche objViewPratiche)
            {
                return this.IDPratica == objViewPratiche.IDPratica;
            }

            return base.Equals(obj);
        }
    }
}